##############################################################################
#
#  List the test cases that are to be disabled temporarily.
#
#  Separate the test case name and the comment with ':'.
#
#    <testcasename> : MDEV-<xxxx> <comment>
#
#  Do not use any TAB characters for whitespace.
#
##############################################################################

galera_2_cluster : MDEV-32631 galera_2_cluster: before_rollback(): Assertion `0' failed
galera_ipv6_rsync : MDEV-34842 Can't connect to server on '::1' (115)
galera_ipv6_rsync_section : MDEV-34842 Can't connect to server on '::1' (115)
galera_ipv6_mariabackup_section : MDEV-34842 Can't connect to server on '::1' (115)
